==> huaweicloudsdkres-3.0.80-py2.py3-none-any.whl: huaweicloudsdkres/v1/model/create_res_workspace_request_body.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateResWorkspaceRequestBody:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'enterprise_project_id': 'str',
        'description': 'str'
    }

    attribute_map = {
        'name': 'name',
        'enterprise_project_id': 'enterprise_project_id',
        'description': 'description'
    }

    def __init__(self, name=None, enterprise_project_id=None, description=None):
        """CreateResWorkspaceRequestBody - a model defined in huaweicloud sdk"""
        
        

        self._name = None
        self._enterprise_project_id = None
        self._description = None
        self.discriminator = None

        self.name = name
        self.enterprise_project_id = enterprise_project_id
        if description is not None:
            self.description = description

    @property
    def name(self):
        """Gets the name of this CreateResWorkspaceRequestBody.

        工作空间名称，1-64位的数字、字母、下划线、中划线组成，支持中文，不能以 - 结尾。

        :return: The name of this CreateResWorkspaceRequestBody.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateResWorkspaceRequestBody.

        工作空间名称，1-64位的数字、字母、下划线、中划线组成，支持中文，不能以 - 结尾。

        :param name: The name of this CreateResWorkspaceRequestBody.
        :type: str
        """
        self._name = name

    @property
    def enterprise_project_id(self):
        """Gets the enterprise_project_id of this CreateResWorkspaceRequestBody.

        企业项目编号。

        :return: The enterprise_project_id of this CreateResWorkspaceRequestBody.
        :rtype: str
        """
        return self._enterprise_project_id

    @enterprise_project_id.setter
    def enterprise_project_id(self, enterprise_project_id):
        """Sets the enterprise_project_id of this CreateResWorkspaceRequestBody.

        企业项目编号。

        :param enterprise_project_id: The enterprise_project_id of this CreateResWorkspaceRequestBody.
        :type: str
        """
        self._enterprise_project_id = enterprise_project_id

    @property
    def description(self):
        """Gets the description of this CreateResWorkspaceRequestBody.

        描述。

        :return: The description of this CreateResWorkspaceRequestBody.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateResWorkspaceRequestBody.

        描述。

        :param description: The description of this CreateResWorkspaceRequestBody.
        :type: str
        """
        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateResWorkspaceRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkres-3.1.7-py2.py3-none-any.whl: huaweicloudsdkres/v1/model/create_res_workspace_request_body.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateResWorkspaceRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'enterprise_project_id': 'str',
        'description': 'str'
    }

    attribute_map = {
        'name': 'name',
        'enterprise_project_id': 'enterprise_project_id',
        'description': 'description'
    }

    def __init__(self, name=None, enterprise_project_id=None, description=None):
        """CreateResWorkspaceRequestBody

        The model defined in huaweicloud sdk

        :param name: 工作空间名称，1-64位的数字、字母、下划线、中划线组成，支持中文，不能以 - 结尾。
        :type name: str
        :param enterprise_project_id: 企业项目编号。
        :type enterprise_project_id: str
        :param description: 描述。
        :type description: str
        """
        
        

        self._name = None
        self._enterprise_project_id = None
        self._description = None
        self.discriminator = None

        self.name = name
        self.enterprise_project_id = enterprise_project_id
        if description is not None:
            self.description = description

    @property
    def name(self):
        """Gets the name of this CreateResWorkspaceRequestBody.

        工作空间名称，1-64位的数字、字母、下划线、中划线组成，支持中文，不能以 - 结尾。

        :return: The name of this CreateResWorkspaceRequestBody.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateResWorkspaceRequestBody.

        工作空间名称，1-64位的数字、字母、下划线、中划线组成，支持中文，不能以 - 结尾。

        :param name: The name of this CreateResWorkspaceRequestBody.
        :type name: str
        """
        self._name = name

    @property
    def enterprise_project_id(self):
        """Gets the enterprise_project_id of this CreateResWorkspaceRequestBody.

        企业项目编号。

        :return: The enterprise_project_id of this CreateResWorkspaceRequestBody.
        :rtype: str
        """
        return self._enterprise_project_id

    @enterprise_project_id.setter
    def enterprise_project_id(self, enterprise_project_id):
        """Sets the enterprise_project_id of this CreateResWorkspaceRequestBody.

        企业项目编号。

        :param enterprise_project_id: The enterprise_project_id of this CreateResWorkspaceRequestBody.
        :type enterprise_project_id: str
        """
        self._enterprise_project_id = enterprise_project_id

    @property
    def description(self):
        """Gets the description of this CreateResWorkspaceRequestBody.

        描述。

        :return: The description of this CreateResWorkspaceRequestBody.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateResWorkspaceRequestBody.

        描述。

        :param description: The description of this CreateResWorkspaceRequestBody.
        :type description: str
        """
        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateResWorkspaceRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
